import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { FlowLog, IVpc, SecurityGroup, Vpc, VpcProps } from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
import { OpenSearchProps } from './opensearch-helper';
import { EndpointTypes } from '../../patterns/gen-ai/aws-rag-appsync-stepfn-kendra/types';
export interface VpcPropsSet {
    readonly existingVpc?: IVpc;
    readonly vpcProps?: VpcProps;
    readonly deployVpc?: boolean;
}
export interface EndpointDefinition {
    endpointName: ServiceEndpointTypeEnum;
    endpointType: EndpointTypes;
    endpointGatewayService?: ec2.GatewayVpcEndpointAwsService;
    endpointInterfaceService?: ec2.InterfaceVpcEndpointAwsService;
}
export declare enum ServiceEndpointTypeEnum {
    DYNAMODB = "DDB",
    ECR_API = "ECR_API",
    ECR_DKR = "ECR_DKR",
    EVENTS = "CLOUDWATCH_EVENTS",
    KENDRA = "KENDRA",
    KINESIS_FIREHOSE = "KINESIS_FIREHOSE",
    KINESIS_STREAMS = "KINESIS_STREAMS",
    S3 = "S3",
    SAGEMAKER_RUNTIME = "SAGEMAKER_RUNTIME",
    SECRETS_MANAGER = "SECRETS_MANAGER",
    SNS = "SNS",
    SQS = "SQS",
    SSM = "SSM",
    STEP_FUNCTIONS = "STEP_FUNCTIONS",
    BEDROCK_RUNTIME = "BEDROCK_RUNTIME",
    COMPREHEND = "COMPREHEND",
    REKOGNITION = "REKOGNITION",
    APP_SYNC = "APP_SYNC"
}
export declare function CheckVpcProps(propsObject: VpcPropsSet | any): void;
export interface BuildVpcProps {
    /**
     * Existing instance of a VPC, if this is set then the all Props are ignored,
     * if this is not set then deafultVPC Props are used.
     */
    readonly existingVpc?: IVpc;
    /**
     * One of the default VPC configurations available in vpc-defaults
     */
    readonly defaultVpcProps?: VpcProps;
    /**
     * User provided props to override the default props for the VPC.
     */
    readonly userVpcProps?: VpcProps;
    /**
     * Construct specified props that override both the default props
     * and user props for the VPC.
     */
    readonly constructVpcProps?: VpcProps;
    /**
     * Name for construct managed VPC.
     */
    readonly vpcName: string;
}
export declare function buildVpc(scope: Construct, props: BuildVpcProps): IVpc;
export declare function getPrivateSubnetIDs(vpc: IVpc): string[];
export declare function getlambdaSecuritygroup(scope: Construct, vpc: IVpc, id: string): SecurityGroup;
/**
 * @internal This is an internal core function and should not be called directly by Solutions Constructs clients.
 *
 * Creates the default vpc props with public , private_with_egress and private_isolated subnet configuration.
 */
export declare function DefaultVpcProps(): VpcProps;
export declare function createOpenSearchVpcEndpoint(scope: Construct, vpc: IVpc, sg: ec2.ISecurityGroup, props: OpenSearchProps): void;
export declare function suppressMapPublicIpWarnings(vpc: Vpc): void;
export declare function suppressEncryptedLogWarnings(flowLog: FlowLog): void;
export declare function createDefaultIsolatedVpcProps(): VpcProps;
export declare function AddAwsServiceEndpoint(scope: Construct, vpc: IVpc, interfaceTags: ServiceEndpointTypeEnum[]): void;
